(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     20502,        479]
NotebookOptionsPosition[     19319,        448]
NotebookOutlinePosition[     19838,        467]
CellTagsIndexPosition[     19795,        464]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["AutoPortrait GUI", "Title",
 CellChangeTimes->{{3.851620422575395*^9, 3.851620442595316*^9}, {
   3.8544680148798313`*^9, 3.8544680227062488`*^9}, 
   3.8544681654220085`*^9},ExpressionUUID->"1eb9db6d-cb9b-4de4-98de-\
be508d805f82"],

Cell["\<\
Automatic Generation of Interactive Multidimensional Phase Portraits
https://lobolab.umbc.edu/autoportrait\
\>", "Subtitle",
 CellChangeTimes->{{3.851620422575395*^9, 3.851620442595316*^9}, {
  3.8544680148798313`*^9, 3.8544680227062488`*^9}, {3.854468094118915*^9, 
  3.85446814741015*^9}, {3.8544684715778856`*^9, 
  3.8544684734800353`*^9}},ExpressionUUID->"b7c2f6f1-32d6-47f5-8bd9-\
e8d495a7dc01"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Get", "[", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", " ", 
      "\"\<AutoPortrait.wl\>\""}], "}"}], "]"}], "]"}], ";"}]], "Input",
 Editable->True,
 CellOpen->False,
 InitializationCell->True,
 CellChangeTimes->{{3.8516135965868216`*^9, 3.8516136189559956`*^9}, 
   3.8516151170299454`*^9, {3.851615477705657*^9, 3.8516155721440444`*^9}, {
   3.851615694421175*^9, 3.851615712343114*^9}, {3.851618634609575*^9, 
   3.851618636323406*^9}, {3.8516210448416967`*^9, 3.8516210657478676`*^9}, {
   3.8516210971142497`*^9, 3.851621131603674*^9}, {3.8516233246287317`*^9, 
   3.851623350398331*^9}, {3.8516234258778067`*^9, 3.8516234413706813`*^9}, 
   3.85162360232821*^9, 3.8516237820444026`*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"20eebaec-e38e-459f-8b8c-7d7cd0aadab5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AutoPortraitGUI", "[", "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.8516236699873886`*^9, 3.851623676675912*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"cbb14c66-8880-4c68-9dbf-d95e25880346"],

Cell[BoxData[
 DynamicModuleBox[{AutoPortrait`Private`n$$ = 3, 
  AutoPortrait`Private`variables$$ = {$CellContext`x1, $CellContext`x2, \
$CellContext`x3, $CellContext`x4, $CellContext`x5, $CellContext`x6, \
$CellContext`x7, $CellContext`x8, $CellContext`x9, $CellContext`x10}, 
  AutoPortrait`Private`equations$$ = {$CellContext`x1, $CellContext`x2, \
$CellContext`x3, $CellContext`x4, $CellContext`x5, $CellContext`x6, \
$CellContext`x7, $CellContext`x8, $CellContext`x9, $CellContext`x10}, 
  AutoPortrait`Private`ps$$ = {}, AutoPortrait`Private`pValues$$ = {}, 
  AutoPortrait`Private`pRanges$$ = {}, AutoPortrait`Private`FindParams$$, 
  AutoPortrait`Private`nplots$$ = 0, AutoPortrait`Private`nonnegative$$ = 
  False, AutoPortrait`Private`newVar$$, AutoPortrait`Private`newFun$$, 
  AutoPortrait`Private`portrait$$ = ""}, 
  TagBox[GridBox[{
     {
      StyleBox["\<\"AutoPortrait\"\>",
       StripOnInput->False,
       FontSize->24,
       FontWeight->Bold]},
     {
      StyleBox["\<\"Automatic Phase Portrait Generator\"\>",
       StripOnInput->False,
       FontSize->20]},
     {
      StyleBox["\<\"Lobo Lab\"\>",
       StripOnInput->False,
       FontSize->16]},
     {"\<\"\"\>"},
     {
      TagBox[GridBox[{
         {"\<\"Number of equations: \"\>", 
          DynamicBox[ToBoxes[AutoPortrait`Private`n$$, StandardForm],
           ImageSizeCache->{7.147461199667305, {0., 9.}}], "\<\" \"\>", 
          
          SliderBox[Dynamic[
           AutoPortrait`Private`n$$, (AutoPortrait`Private`portrait$$ = ""; 
            AutoPortrait`Private`n$$ = #; 
            AutoPortrait`Private`FindParams$$[])& ], {2, 10, 1},
           ImageSize->340]},
         {"\<\"Nonnegative domain: \"\>", 
          
          CheckboxBox[Dynamic[
           AutoPortrait`Private`nonnegative$$, (
            AutoPortrait`Private`portrait$$ = ""; 
            AutoPortrait`Private`nonnegative$$ = #)& ]], "", ""}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Right}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {
      DynamicBox[ToBoxes[
        Grid[{{
           Column[{"Differential Equations:", 
             Grid[
              Table[
               With[{AutoPortrait`Private`$i$ = AutoPortrait`Private`$i}, {
                 OverDot[
                  InputField[
                   Dynamic[
                    InputForm[
                    Part[
                    AutoPortrait`Private`variables$$, 
                    AutoPortrait`Private`$i$]], (
                    Part[AutoPortrait`Private`variables$$, 
                    AutoPortrait`Private`$i$] = Part[
                    Cases[{#}, 
                    Blank[Symbol], Infinity], 1]; 
                    AutoPortrait`Private`FindParams$$[]; 
                    AutoPortrait`Private`portrait$$ = "")& ], 
                   FieldSize -> {{1, 40}, Small}]], "=", 
                 InputField[
                  Dynamic[
                   InputForm[
                    Part[
                    AutoPortrait`Private`equations$$, 
                    AutoPortrait`Private`$i$]], (
                   Part[AutoPortrait`Private`equations$$, 
                    AutoPortrait`Private`$i$] = #; 
                   AutoPortrait`Private`FindParams$$[]; 
                   AutoPortrait`Private`portrait$$ = "")& ], 
                  FieldSize -> {{1, 40}, Small}]}], {
               AutoPortrait`Private`$i, AutoPortrait`Private`n$$}], Alignment -> 
              Left]}, Center, Frame -> True, FrameStyle -> Directive[
              Thickness[0.5]]], 
           If[Length[AutoPortrait`Private`ps$$] > 0, 
            Column[{"Parameters:", 
              Grid[
               Table[
                With[{AutoPortrait`Private`$i$ = AutoPortrait`Private`$i}, {
                  Part[AutoPortrait`Private`ps$$, AutoPortrait`Private`$i$], 
                  "=", 
                  InputField[
                   Dynamic[
                    Part[
                    AutoPortrait`Private`pValues$$, 
                    AutoPortrait`Private`$i$]], Number, 
                   FieldSize -> {{1, 80}, Small}], "  ", 
                  Part[AutoPortrait`Private`ps$$, AutoPortrait`Private`$i$], 
                  "\[Element]", "[", 
                  InputField[
                   Dynamic[
                    Part[
                    AutoPortrait`Private`pRanges$$, AutoPortrait`Private`$i$, 
                    1]], Number, FieldSize -> {{1, 40}, Small}], ",", 
                  InputField[
                   Dynamic[
                    Part[
                    AutoPortrait`Private`pRanges$$, AutoPortrait`Private`$i$, 
                    2]], Number, FieldSize -> {{1, 40}, Small}], "]"}], {
                AutoPortrait`Private`$i, 
                 Length[AutoPortrait`Private`ps$$]}], Alignment -> Left]}, 
             Center, Frame -> True, FrameStyle -> Directive[
               Thickness[0.5]]], ""]}}, Alignment -> Top], StandardForm],
       ImageSizeCache->{177., {52.134033098001964`, 57.865966901998036`}}]},
     {
      ButtonBox[
       StyleBox["\<\"Generate portraits\"\>",
        StripOnInput->False,
        FontSize->12],
       Appearance->Automatic,
       ButtonFunction:>(AutoPortrait`Private`portrait$$ = 
        AutoPortrait`GeneratePortrait[
          Take[AutoPortrait`Private`equations$$, AutoPortrait`Private`n$$], 
          Take[AutoPortrait`Private`variables$$, AutoPortrait`Private`n$$], 
          AutoPortrait`Private`ParamValues -> 
          MapThread[# -> #2& , {
            AutoPortrait`Private`ps$$, AutoPortrait`Private`pValues$$}], 
          AutoPortrait`Private`ParamRanges -> 
          MapThread[# -> #2& , {
            AutoPortrait`Private`ps$$, AutoPortrait`Private`pRanges$$}], 
          AutoPortrait`Private`NonNegativeDomain -> 
          AutoPortrait`Private`nonnegative$$, AutoPortrait`Private`NumColumns -> 
          OptionValue[{
            AutoPortrait`Private`NumColumns -> 3, 
             AutoPortrait`Private`ShowLegend -> True}, {}, 
            AutoPortrait`Private`NumColumns], AutoPortrait`Private`ShowLegend -> 
          OptionValue[{
            AutoPortrait`Private`NumColumns -> 3, 
             AutoPortrait`Private`ShowLegend -> True}, {}, 
            AutoPortrait`Private`ShowLegend]]),
       Evaluator->Automatic,
       Method->"Preemptive"]},
     {
      DynamicBox[ToBoxes[AutoPortrait`Private`portrait$$, StandardForm],
       ImageSizeCache->{0., {0., 7.}}]}
    },
    DefaultBaseStyle->"Column",
    FrameStyle->Directive[
      Thickness[1]],
    GridBoxAlignment->{"Columns" -> {{Center}}},
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Column"],
  DynamicModuleValues:>{{
    DownValues[AutoPortrait`Private`FindParams$$] = {HoldPattern[
         AutoPortrait`Private`FindParams$$[]] :> 
       Module[{AutoPortrait`Private`psv$ = 
          MapThread[# -> #2& , {
            AutoPortrait`Private`ps$$, AutoPortrait`Private`pValues$$}], 
          AutoPortrait`Private`psr$ = 
          MapThread[# -> #2& , {
            AutoPortrait`Private`ps$$, AutoPortrait`Private`pRanges$$}]}, 
         AutoPortrait`Private`ps$$ = DeleteCases[
            DeleteDuplicates[
             Cases[
              Take[
              AutoPortrait`Private`equations$$, AutoPortrait`Private`n$$], 
              Blank[Symbol], Infinity]], 
            Apply[Alternatives, 
             Take[
             AutoPortrait`Private`variables$$, AutoPortrait`Private`n$$]]]; 
         AutoPortrait`Private`pValues$$ = ReplaceAll[
            ReplaceAll[AutoPortrait`Private`ps$$, AutoPortrait`Private`psv$], 
            Map[# -> 1& , AutoPortrait`Private`ps$$]]; 
         AutoPortrait`Private`pRanges$$ = ReplaceAll[
            ReplaceAll[AutoPortrait`Private`ps$$, AutoPortrait`Private`psr$], 
            Map[# -> {0, 2}& , AutoPortrait`Private`ps$$]]; 
         Null]}}}]], "Output",
 CellOpen->False,
 CellChangeTimes->{
  3.851623677113353*^9, {3.8516244286788964`*^9, 3.851624440658159*^9}, 
   3.8523172868489246`*^9, 3.854468176800605*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"ab11bdee-6a3d-406e-a858-3703a73c03d9"]
}, Closed]],

Cell["\<\
Select number of independent variables (equations) and type them in the \
boxes. \[LineSeparator]Click the button to generate the portraits.\
\>", "Text",
 CellChangeTimes->{{3.851624077811641*^9, 3.851624106951624*^9}, {
   3.854468231970113*^9, 3.854468233039339*^9}, {3.8544682805227056`*^9, 
   3.8544683103547487`*^9}, 
   3.854468458415472*^9},ExpressionUUID->"982d9d83-135c-445f-bb8c-\
bccdf72d2049"],

Cell[BoxData[
 DynamicModuleBox[{AutoPortrait`Private`n$$ = 3, 
  AutoPortrait`Private`variables$$ = {$CellContext`x1, $CellContext`x2, \
$CellContext`x3, $CellContext`x4, $CellContext`x5, $CellContext`x6, \
$CellContext`x7, $CellContext`x8, $CellContext`x9, $CellContext`x10}, 
  AutoPortrait`Private`equations$$ = {$CellContext`x1, $CellContext`x2, \
$CellContext`x3, $CellContext`x4, $CellContext`x5, $CellContext`x6, \
$CellContext`x7, $CellContext`x8, $CellContext`x9, $CellContext`x10}, 
  AutoPortrait`Private`ps$$ = {}, AutoPortrait`Private`pValues$$ = {}, 
  AutoPortrait`Private`pRanges$$ = {}, AutoPortrait`Private`FindParams$$, 
  AutoPortrait`Private`nplots$$ = 0, AutoPortrait`Private`nonnegative$$ = 
  False, AutoPortrait`Private`newVar$$, AutoPortrait`Private`newFun$$, 
  AutoPortrait`Private`portrait$$ = ""}, 
  TagBox[GridBox[{
     {
      StyleBox["\<\"AutoPortrait\"\>",
       StripOnInput->False,
       FontSize->24,
       FontWeight->Bold]},
     {
      StyleBox["\<\"Automatic Phase Portrait Generator\"\>",
       StripOnInput->False,
       FontSize->20]},
     {
      StyleBox["\<\"Lobo Lab\"\>",
       StripOnInput->False,
       FontSize->16]},
     {"\<\"\"\>"},
     {
      TagBox[GridBox[{
         {"\<\"Number of equations: \"\>", 
          DynamicBox[ToBoxes[AutoPortrait`Private`n$$, StandardForm],
           ImageSizeCache->{7.147461199667305, {0., 9.}}], "\<\" \"\>", 
          
          SliderBox[Dynamic[
           AutoPortrait`Private`n$$, (AutoPortrait`Private`portrait$$ = ""; 
            AutoPortrait`Private`n$$ = #; 
            AutoPortrait`Private`FindParams$$[])& ], {2, 10, 1},
           ImageSize->340]},
         {"\<\"Nonnegative domain: \"\>", 
          
          CheckboxBox[Dynamic[
           AutoPortrait`Private`nonnegative$$, (
            AutoPortrait`Private`portrait$$ = ""; 
            AutoPortrait`Private`nonnegative$$ = #)& ]], "", ""}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Right}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {
      DynamicBox[ToBoxes[
        Grid[{{
           Column[{"Differential Equations:", 
             Grid[
              Table[
               With[{AutoPortrait`Private`$i$ = AutoPortrait`Private`$i}, {
                 OverDot[
                  InputField[
                   Dynamic[
                    InputForm[
                    Part[
                    AutoPortrait`Private`variables$$, 
                    AutoPortrait`Private`$i$]], (
                    Part[AutoPortrait`Private`variables$$, 
                    AutoPortrait`Private`$i$] = Part[
                    Cases[{#}, 
                    Blank[Symbol], Infinity], 1]; 
                    AutoPortrait`Private`FindParams$$[]; 
                    AutoPortrait`Private`portrait$$ = "")& ], 
                   FieldSize -> {{1, 40}, Small}]], "=", 
                 InputField[
                  Dynamic[
                   InputForm[
                    Part[
                    AutoPortrait`Private`equations$$, 
                    AutoPortrait`Private`$i$]], (
                   Part[AutoPortrait`Private`equations$$, 
                    AutoPortrait`Private`$i$] = #; 
                   AutoPortrait`Private`FindParams$$[]; 
                   AutoPortrait`Private`portrait$$ = "")& ], 
                  FieldSize -> {{1, 40}, Small}]}], {
               AutoPortrait`Private`$i, AutoPortrait`Private`n$$}], Alignment -> 
              Left]}, Center, Frame -> True, FrameStyle -> Directive[
              Thickness[0.5]]], 
           If[Length[AutoPortrait`Private`ps$$] > 0, 
            Column[{"Parameters:", 
              Grid[
               Table[
                With[{AutoPortrait`Private`$i$ = AutoPortrait`Private`$i}, {
                  Part[AutoPortrait`Private`ps$$, AutoPortrait`Private`$i$], 
                  "=", 
                  InputField[
                   Dynamic[
                    Part[
                    AutoPortrait`Private`pValues$$, 
                    AutoPortrait`Private`$i$]], Number, 
                   FieldSize -> {{1, 80}, Small}], "  ", 
                  Part[AutoPortrait`Private`ps$$, AutoPortrait`Private`$i$], 
                  "\[Element]", "[", 
                  InputField[
                   Dynamic[
                    Part[
                    AutoPortrait`Private`pRanges$$, AutoPortrait`Private`$i$, 
                    1]], Number, FieldSize -> {{1, 40}, Small}], ",", 
                  InputField[
                   Dynamic[
                    Part[
                    AutoPortrait`Private`pRanges$$, AutoPortrait`Private`$i$, 
                    2]], Number, FieldSize -> {{1, 40}, Small}], "]"}], {
                AutoPortrait`Private`$i, 
                 Length[AutoPortrait`Private`ps$$]}], Alignment -> Left]}, 
             Center, Frame -> True, FrameStyle -> Directive[
               Thickness[0.5]]], ""]}}, Alignment -> Top], StandardForm],
       ImageSizeCache->{177., {52.134033098001964`, 57.865966901998036`}}]},
     {
      ButtonBox[
       StyleBox["\<\"Generate portraits\"\>",
        StripOnInput->False,
        FontSize->12],
       Appearance->Automatic,
       ButtonFunction:>(AutoPortrait`Private`portrait$$ = 
        AutoPortrait`GeneratePortrait[
          Take[AutoPortrait`Private`equations$$, AutoPortrait`Private`n$$], 
          Take[AutoPortrait`Private`variables$$, AutoPortrait`Private`n$$], 
          AutoPortrait`Private`ParamValues -> 
          MapThread[# -> #2& , {
            AutoPortrait`Private`ps$$, AutoPortrait`Private`pValues$$}], 
          AutoPortrait`Private`ParamRanges -> 
          MapThread[# -> #2& , {
            AutoPortrait`Private`ps$$, AutoPortrait`Private`pRanges$$}], 
          AutoPortrait`Private`NonNegativeDomain -> 
          AutoPortrait`Private`nonnegative$$, AutoPortrait`Private`NumColumns -> 
          OptionValue[{
            AutoPortrait`Private`NumColumns -> 3, 
             AutoPortrait`Private`ShowLegend -> True}, {}, 
            AutoPortrait`Private`NumColumns], AutoPortrait`Private`ShowLegend -> 
          OptionValue[{
            AutoPortrait`Private`NumColumns -> 3, 
             AutoPortrait`Private`ShowLegend -> True}, {}, 
            AutoPortrait`Private`ShowLegend]]),
       Evaluator->Automatic,
       Method->"Preemptive"]},
     {
      DynamicBox[ToBoxes[AutoPortrait`Private`portrait$$, StandardForm],
       ImageSizeCache->{0., {0., 7.}}]}
    },
    DefaultBaseStyle->"Column",
    FrameStyle->Directive[
      Thickness[1]],
    GridBoxAlignment->{"Columns" -> {{Center}}},
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Column"],
  DynamicModuleValues:>{{
    DownValues[AutoPortrait`Private`FindParams$$] = {HoldPattern[
         AutoPortrait`Private`FindParams$$[]] :> 
       Module[{AutoPortrait`Private`psv$ = 
          MapThread[# -> #2& , {
            AutoPortrait`Private`ps$$, AutoPortrait`Private`pValues$$}], 
          AutoPortrait`Private`psr$ = 
          MapThread[# -> #2& , {
            AutoPortrait`Private`ps$$, AutoPortrait`Private`pRanges$$}]}, 
         AutoPortrait`Private`ps$$ = DeleteCases[
            DeleteDuplicates[
             Cases[
              Take[
              AutoPortrait`Private`equations$$, AutoPortrait`Private`n$$], 
              Blank[Symbol], Infinity]], 
            Apply[Alternatives, 
             Take[
             AutoPortrait`Private`variables$$, AutoPortrait`Private`n$$]]]; 
         AutoPortrait`Private`pValues$$ = ReplaceAll[
            ReplaceAll[AutoPortrait`Private`ps$$, AutoPortrait`Private`psv$], 
            Map[# -> 1& , AutoPortrait`Private`ps$$]]; 
         AutoPortrait`Private`pRanges$$ = ReplaceAll[
            ReplaceAll[AutoPortrait`Private`ps$$, AutoPortrait`Private`psr$], 
            Map[# -> {0, 2}& , AutoPortrait`Private`ps$$]]; 
         Null]}}}]], "Output",
 CellChangeTimes->{{3.8544684133682575`*^9, 
  3.854468426967746*^9}},ExpressionUUID->"70e6595a-15ea-49f4-ba4f-\
4246faa0318e"]
}, Open  ]]
},
InitializationCellEvaluation->True,
InitializationCellWarning->False,
WindowSize->{1428., 743.25},
WindowMargins->{{1440, Automatic}, {Automatic, 0}},
TaggingRules-><|"TryRealOnly" -> False|>,
FrontEndVersion->"13.0 for Microsoft Windows (64-bit) (December 2, 2021)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"66e53c76-b5f3-4e62-bfb1-80681d4b832e"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 238, 4, 98, "Title",ExpressionUUID->"1eb9db6d-cb9b-4de4-98de-be508d805f82"],
Cell[821, 28, 411, 8, 85, "Subtitle",ExpressionUUID->"b7c2f6f1-32d6-47f5-8bd9-e8d495a7dc01"],
Cell[1235, 38, 881, 18, 19, "Input",ExpressionUUID->"20eebaec-e38e-459f-8b8c-7d7cd0aadab5",
 CellOpen->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2141, 60, 227, 4, 19, "Input",ExpressionUUID->"cbb14c66-8880-4c68-9dbf-d95e25880346",
 CellOpen->False],
Cell[2371, 66, 8304, 184, 19, "Output",ExpressionUUID->"ab11bdee-6a3d-406e-a858-3703a73c03d9",
 CellOpen->False]
}, Closed]],
Cell[10690, 253, 417, 8, 54, "Text",ExpressionUUID->"982d9d83-135c-445f-bb8c-bccdf72d2049"],
Cell[11110, 263, 8193, 182, 311, "Output",ExpressionUUID->"70e6595a-15ea-49f4-ba4f-4246faa0318e"]
}, Open  ]]
}
]
*)

